@@ -1,19 +1,16 @@
 static char *TEAM_LIST[] = {
-"Holger Berndt <berndth@users.sf.net>",
+"Jonathan Boeing <jonathan@claws-mail.org>",
 "Tristan Chabredier <wwp@claws-mail.org>",
-"Andrej Kacian <andrej@kacian.sk>",
-"Darko Koruga <darko@users.sf.net>",
-"Charles Lehner <charles@claws-mail.org>",
-"Colin Leroy <colin@colino.net>",
+"Thorsten Maerz <thorsten@claws-mail.org>",
 "Paul Mangan <paul@claws-mail.org>",
 "Ricardo Mones Lastra <ricardo@mones.org>",
 "Salvatore De Paolis <iwkse@claws-mail.org>",
-"Paweł Pękala <c0rn@o2.pl>",
 "Michael Rasmussen <mir@datanom.net>",
 NULL
 };
 
 static char *EX_TEAM_LIST[] = {
+"Holger Berndt",
 "Hoà Viêt Dinh",
 "Keith Edmunds",
 "Match Grun",
@@ -21,8 +18,12 @@ static char *EX_TEAM_LIST[] = {
 "Oliver Haertel",
 "Christoph Hohmann",
 "Alfons Hoogervorst",
+"Andrej Kacian",
 "Werner Koch",
-"Thorsten Maerz",
+"Darko Koruga",
+"Charles Lehner",
+"Colin Leroy-Mira",
+"Paweł Pękala",
 "Leandro A. F. Pereira",
 "Luke Plant",
 "Martin Schaaf",
@@ -37,18 +38,21 @@ static char *TRANS_TEAM_LIST[] = {
 "[ca] David Medina <opensusecatala@gmail.com>",
 "[cs] David Vachulka <david@konstrukce-cad.com>",
 "[da] Erik P. Olsen <epodata@gmail.com>",
-"[de] Simon Legner <simon.legner@gmail.com>",
+"[de] Simon Legner",
 "[en_GB] Paul Mangan <paul@claws-mail.org>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
 "[fi] Flammie Pirinen <flammie@iki.fi>",
 "[fr] Tristan Chabredier <wwp@claws-mail.org>",
-"[he] Isratine Citizen <genghiskhan@gmx.ca>",
 "[hu] Páder Rezső <rezso@rezso.net>",
 "[id_ID] MSulchan Darmawan <bleketux@gmail.com>",
 "[it] Luigi Votta <luigi.vtt@gmail.com>",
+"[ja] UTUMI Hirosi <utuhiro78@yahoo.co.jp>",
 "[nb] Petter Adsen <petter@synth.no>",
 "[nl] Marcel Pol <mpol@gmx.net>",
+"[pl] Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>",
 "[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
+"[pt_PT] Hugo Carvalho <hugokarvalho@hotmail.com>",
+"[ro] Cristian Secară <liste@secarica.ro>",
 "[ru] Mikhail Kurinnoi <viewizard@viewizard.com>",
 "[sk] Slavko <slavino@slavino.sk>",
 "[sv] Andreas Rönnquist <gusnan@openmailbox.org>",
@@ -60,12 +64,10 @@ NULL
 static char *DOC_TEAM_LIST[] = {
 "[en] Tristan Chabredier <wwp@claws-mail.org>",
 "     Ricardo Mones Lastra <ricardo@mones.org>",
-"     Colin Leroy <colin@colino.net>",
 "     Paul Mangan <paul@claws-mail.org>",
+"[de] Christoph Klassen <christoph.klassen@intevation.de>",
 "[es] Ricardo Mones Lastra <ricardo@mones.org>",
 "[fr] Tristan Chabredier <wwp@claws-mail.org>",
-"     Colin Leroy <colin@colino.net>",
-"[pl] Paweł Pękala <c0rn@gazeta.pl>",
 NULL
 };
 
@@ -97,7 +99,7 @@ static char *CONTRIBS_LIST[] = {
 "Laurent Bigonville",
 "Jean-Luc Biord",
 "Blatinox",
-"Hanno Boeck",
+"Hanno Böck",
 "Pavlo Bohmat",
 "Ralf Bormann",
 "H. Merijn Brand",
@@ -107,6 +109,7 @@ static char *CONTRIBS_LIST[] = {
 "Anton Butanaev",
 "Henrik Carlqvist",
 "Luca Cavalli",
+"Gianni Ceccarelli",
 "David Chalmers",
 "Wei-Lun Chao",
 "Guillaume Chazarain",
@@ -122,7 +125,9 @@ static char *CONTRIBS_LIST[] = {
 "Kevin Day",
 "Matthieu Dazy",
 "Ben Deering",
+"Jean Delvare",
 "Pierric Descamps",
+"Orivej Desh",
 "Rodrigo Dias Arruda Senra",
 "Frank Dietrich",
 "Tim Dijkstra",
@@ -138,6 +143,7 @@ static char *CONTRIBS_LIST[] = {
 "Tiago Faria",
 "Alessandro Di Federico",
 "Lars Persson Fink",
+"David Fletcher",
 "Bob Forsman",
 "Matthias Förste",
 "Ivan Francolin Martinez",
@@ -145,6 +151,7 @@ static char *CONTRIBS_LIST[] = {
 "Stavros Giannouris",
 "Thomas Gilgin",
 "Marius Glauser",
+"Michael Gmelin",
 "Thierry Godefroy",
 "Alex Gorbachenko",
 "Michał Górny",
@@ -152,21 +159,25 @@ static char *CONTRIBS_LIST[] = {
 "Yang Guilong",
 "Ashish Gupta",
 "Daniel Gustafson",
-"HIROSHIMA",
+"Roland Haas",
 "Oliver Haertel",
 "Anders Hammar",
 "Mitko Haralanov",
+"Alexander Lyons Harkness",
 "Hashimoto",
 "Jacob Head",
 "Federico Heinz",
 "Geir Helland",
 "Jorge Van Hemelryck",
+"Olaf Hering",
 "Christian Hesse",
 "Higuchi",
 "Hiramatu",
+"HIROSHIMA",
 "Marc Hoper",
 "Michihide Hotta",
 "Shawn Houston",
+"Charles Huber",
 "Michael Hughes",
 "Richard Hughes",
 "Arthur Huillet",
@@ -189,12 +200,14 @@ static char *CONTRIBS_LIST[] = {
 "kazken3",
 "WAKAI Kazunao",
 "Fabian Keil",
+"Jakub Kiciński",
 "Martin Kluge",
 "IWAMOTO Kouichi",
 "Mikhail Kurinnoi",
 "Abhay S. Kushwaha",
 "Joshua M. Kwan",
 "Jean-Yves Lefort",
+"Flavio Leitner",
 "Jérôme Lelong",
 "Eric Limpens",
 "Thomas Link",
@@ -215,10 +228,12 @@ static char *CONTRIBS_LIST[] = {
 "Bram Metsch",
 "Hanno Meyer-Thurow",
 "George Michaelson",
+"Raphael Michel",
 "Florian Mickler",
 "Neill Miller",
 "Suzuki Mio",
 "Alex S Moore",
+"Frank Mueller",
 "NAKAGAWA",
 "Yuuki NINOMIYA",
 "Satoshi Nagayasu",
@@ -234,6 +249,7 @@ static char *CONTRIBS_LIST[] = {
 "Ales Nosek",
 "Emilian Nowak",
 "James Noyes",
+"nycex",
 "Jens Oberender",
 "Ofer",
 "Ohmasa",
@@ -241,15 +257,20 @@ static char *CONTRIBS_LIST[] = {
 "Paul Ollis",
 "Fredrik Olofssen",
 "Orbea",
+"Thomas Orgis",
 "Reza Pakdel",
 "Richard Palo",
+"Alvar Penning",
+"Damian Poddebniak",
 "Marcel Pol",
 "Martin Pool",
 "Quar",
 "Don Quijote",
 "Steve Rader",
+"Steve Randall",
 "Jens Rantil",
 "Ravemax",
+"Eric S. Raymond",
 "Ivan Rayner",
 "David Relson",
 "Volker Ribbert",
@@ -268,18 +289,24 @@ static char *CONTRIBS_LIST[] = {
 "Simon 'corecode' Schubert",
 "Kim Schulz",
 "Markus Schwarzenberg",
+"Michael Schwendt",
+"Ralph Sennhauser",
 "Setoh",
 "Michael Shell",
 "shigeri",
 "Jesse Skinner",
 "Ville Skyttä",
+"Alex Smith",
 "Dale P. Smith",
+"Avinash Sonawane",
 "Andrea Spadaccini",
+"Manuel Stoeckl",
 "Bogdan Sumanariu",
 "TAKANO",
 "TOGAWA",
 "Tajiri",
 "Takahashi",
+"Sakaguchi Takayuki",
 "Tanaka",
 "Shimamoto \"Neko\" Tatsuya",
 "Timo Teräs",
@@ -289,11 +316,13 @@ static char *CONTRIBS_LIST[] = {
 "Masahiro Tomita",
 "Tomita",
 "Topia",
+"Ramin Yaghoubzadeh Torky",
 "Anders Troback",
 "Tsutsui",
 "Aleksandar Urošević",
 "Petr Vanek",
 "Jeroen Versteeg",
+"Viatrix",
 "Kevin Vigor",
 "Michael Vilain",
 "Johan Vromans",
@@ -302,7 +331,9 @@ static char *CONTRIBS_LIST[] = {
 "Jonathan Ware",
 "Watanabe",
 "Rafal Weglarz",
+"Florian Weimer",
 "Martin Wicke",
+"Paul Wolneykien",
 "Bob Woodside",
 "YAMAGUCHI",
 "T. Yamamoto",
